@@ -26,7 +26,8 @@ __all__ = [
 
 
 import datetime
-import dateutil
+
+import dateutil.parser
 
 from .cache import (
     Cache
@@ -141,6 +142,10 @@ class YoutubeVideoMetadataDownloader(YoutubeMetadataDownloader):
         if len(periods) > 1:
             periods = sum(periods)
         with Cache() as cache:
+            try:
+                cache[self.search_terms]
+            except KeyError:
+                cache[self.search_terms] = {}
             cache[self.search_terms]["already downloaded periods"] = \
                 periods
 
@@ -174,17 +179,25 @@ class YoutubeVideoMetadataDownloader(YoutubeMetadataDownloader):
         while len(self._already_downloaded_periods) > 1:
             # until we’ve caught up completely and there’s
             # no gaps in our data collection history
+
+            published_at = None
+
             for item in self.items:
                 video = YoutubeVideo(item)
                 YoutubeCommentThreadDownloader(video.orig_id).download()
                 del video
 
+                published_at = dateutil.parser.isoparse(
+                    item["snippet"]["publishedAt"]
+                )
                 self._already_downloaded_periods += \
                     TimeSpan(
-                        dateutil.parser.isoparse(
-                            item["snippet"]["publishedAt"]
-                        ),
+                        published_at,
                         self._current_gap.end
                     )
 
-            self._already_downloaded_periods += self._current_gap
+            self._already_downloaded_periods += \
+                TimeSpan(
+                    self._current_gap.start,
+                    self._current_gap.end
+                )
